"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var match_path_1 = require("./match-path");
var config_loader_1 = require("./config-loader");
/**
 * Installs a custom module load function that can adhere to paths in tsconfig.
 */
function register(explicitParams) {
    var configLoaderResult = config_loader_1.configLoader({
        cwd: process.cwd(),
        explicitParams: explicitParams
    });
    if (configLoaderResult.resultType === "failed") {
        console.warn(configLoaderResult.message + ". tsconfig-paths will be skipped");
        return;
    }
    var matchPath = match_path_1.createMatchPath(configLoaderResult.absoluteBaseUrl, configLoaderResult.paths);
    // Patch node's module loading
    var Module = require("module");
    var originalResolveFilename = Module._resolveFilename;
    Module._resolveFilename = function (request, parent) {
        var found = matchPath(parent, request);
        if (found) {
            var modifiedArguments = [found].concat([].slice.call(arguments, 1)); // Passes all arguments. Even those that is not specified above.
            return originalResolveFilename.apply(this, modifiedArguments);
        }
        return originalResolveFilename.apply(this, arguments);
    };
}
exports.register = register;
